bear (bear) on Twitter

## Tweet to bear

Drag photo here Or drag photo here Tweet text
Image will appear as a link
Add Photo
140
Photos and videos

### Who to follow

·
· View all

### Philadelphia

· Change

# bear

## @bear follows you

Opsasaurus Ursus for &yet -- Python, XMPP, DevOps and Messaging developer

Philadelphia · bear.im

Followed by Julien Genestoux, Michael Speegle, fritzy and 19 others.

### Trends

## Trends tailored just for you.

Trends offer a unique way to get closer to what you care about. They are tailored for you based on your location and who you follow.

## Tweets

1. Ben Werdmüller ‏@benwerd 22h

   A quick video demo of #indieweb replies, events and RSVPs, brid.gy, and the Firefox Social API: http://www.youtube.com/watch?v=XxYf7xhebOI …

2. bear ‏@bear 22h

   @bdha I do but only if the test code runs and passes

3. Ian Melven ‏@imelven 23h

   New Relic is looking for a Information Security Analyst/Engineer in either San Francisco or Portland ! see http://newrelic.com/about/jobs

4. bear ‏@bear 10 Jan

   @renrutnnej nice beer!

5. bear ‏@bear 10 Jan

   Drinking an El Conquistador by @missionbrewery @ Dog And Bull Brew & Music House — http://untp.it/1c2nNSo

6. bear ‏@bear 10 Jan

   Drinking an Islander IPA by @coronadobrewing @ Dog And Bull Brew & Music House — http://untp.it/1dEcReS

7. Donnie Berkholz ‏@dberkholz 10 Jan

   MT @markimbriaco: Poor outage communication upsets me. It isn’t rocket science, you just have to care. http://monk.ly/1af0YeP —Watch now.

8. bear ‏@bear 10 Jan

   @bhearsum \o/ that's like finding money in a coat you haven't worn in long time!

9. PigtailPals.com ‏@PigtailPals 10 Jan

   "Connect the Dots: How That Sexualized Doll Plays Into Child Sex Trafficking" http://pigtailpalsblog.com/?p=4933 Use your voice. Be the solution.

10. hangops ‏@hangops 10 Jan

    #hangops - talking about remote work tips, tricks, and culture - participate: https://plus.google.com/hangouts/_/hoaevent/AP36tYcgNCSft7r2RfCrm1J92wgLlYN1lHGD-5S3kq2B1Ew2l4omEg?authuser=0&hl=en … - watch: http://www.youtube.com/embed/KuGdKuKxzKo …

11. bear ‏@bear 10 Jan

    @funkatron I had to switch shampoo because of that kind of reaction my cats had to it… either that or stop using catnip laced hair gel?

12. bear ‏@bear 10 Jan

    Quick note for all the #XMPP folks - details for the 15th XMPP Summit are being nailed down - http://wiki.xmpp.org/web/Summit_15

13. bear ‏@bear 10 Jan

    @roidrage congrats and a big ^5 to the team!

14. bear ‏@bear 9 Jan

    hopefully not one of those nasty gluten free snacks! @quitlahok @stpeter

15. Christian Legnitto ‏@LegNeato 9 Jan

    My team at @facebook is looking for a release engineer / manager / project manager in New York (experienced or junior)...know anyone?

16. bear ‏@bear 9 Jan

    @sogrady add beer to that article and you have a trifecta of interest items for you

17. bear ‏@bear 9 Jan

    double +1 RT @sogrady: the tech people who follow me are going to want to read this: "Software in 2014" by @timbray: https://www.tbray.org/ongoing/When/201x/2014/01/01/Software-in-2014 …

18. bear ‏@bear 8 Jan

    Drinking a Lambickx by Brouwerij Strubbe @ Wednesday Night Bottle Share — http://untp.it/1lS6Dww

19. bear ‏@bear 8 Jan

    I just earned the 'Pucker Up (Level 6)' badge on @untappd! http://untp.it/1iVZgXO

20. bear ‏@bear 8 Jan

    Drinking a Yeti by @greatdividebrew @ Dog And Bull Brew & Music House — http://untp.it/1bTfE2B

## Loading seems to be taking a while.

Twitter may be over capacity or experiencing a momentary hiccup. Try again or visit Twitter Status for more information.

### Flag this media

This has already been marked as containing sensitive content.

Flag this as containing potentially illegal content.

### We’re loading your contacts…

(This can take a while if you’ve got a large address book.)

×

##

### Direct messages

You don't have any messages yet.

Direct messages are 140 characters, private, and can be sent to any user who follows you on Twitter.

### Direct messages › with

Drag photo here Or drag photo here Direct message text
Add Photo
140

Are you sure you want to delete this message?

Do you want to report this message as spam?

### Direct messages › New

Drag photo here Or drag photo here Direct message text
Add Photo
140

Are you sure you want to delete this message?

Do you want to report this message as spam?

## Photo

###

Drag photo here Or drag photo here Tweet text
Image will appear as a link
Add Photo
140

### Go to a person's profile

### Retweet this to your followers?

### Are you sure you want to delete this Tweet?

### Keyboard shortcuts

### Are you sure you want to block this user?

/div>

### Profile summary

### Your lists

### Create a new list

List name
List link

Description Under 100 characters, optional

Privacy
Public · Anyone can follow this list Private · Only you can access this list

###

###

### Share via email

From: &yet (Twitter)
To:

Include my email address (adam@andyet.net) so recipients can reply to me.

### Embed this Tweet

Add this Tweet to your website by copying the code below. Learn more

Hmm, there was a problem reaching the server.

Include parent Tweet
Include media

### Preview

### Report Tweet

### Select form

Spam

This Tweet may be spam or from a spam account.

Compromised

This user may not be in control of their account.

Abusive

This Tweet may be in violation of the Twitter Rules. In order to file a report you must still choose and complete a form. Select this option to continue.

Learn more about what blocking means.

Please choose the topic that best defines your issue. Once you complete and submit the form, your report will be filed with Twitter.

- Impersonation
- Trademarks
- Harassment
- Report self harm
- Report an ad

### Enter your age

To follow this account, you must be of legal drinking age. Please supply your date of birth.

Select your date of birth:

Required
Privacy policy
Drag photo here Or drag photo here Tweet text
Image will appear as a link
div class="image-selector"> Add Photo
140